==> cscec5b-rmat-impl-3.0.1-20241010.112942-311-sources.jar: com/ejianc/business/rmat/service/impl/StopBpmServiceImpl.java <==
package com.ejianc.business.rmat.service.impl;

import com.ejianc.business.rmat.bean.StopEntity;
import com.ejianc.business.rmat.consts.MaterialConstant;
import com.ejianc.business.rmat.consts.RmatCommonConsts;
import com.ejianc.business.rmat.service.IPriceFlowService;
import com.ejianc.business.rmat.service.IRmatFlowService;
import com.ejianc.business.rmat.service.IStopService;
import com.ejianc.business.rmat.vo.StopVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service("stop")
public class StopBpmServiceImpl implements ICommonBusinessService {
	private final Logger logger = LoggerFactory.getLogger(getClass());
	@Autowired
	private IRmatFlowService rmatFlowService;
	@Autowired
	private IStopService service;
	@Autowired
	private IPriceFlowService priceFlowService;
	@Autowired
	private IBillTypeApi billTypeApi;

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		StopEntity entity = service.selectById(billId);
		// 推送租赁流水生效
		if(!rmatFlowService.insertStopFlow(entity, billTypeCode, RmatCommonConsts.YES)){
			return CommonResponse.error("审批回调失败，单据推送流水失败！");
		}

		// 推送单价流水生效
		if (!priceFlowService.insertStopFlow(entity, billTypeCode)) {
			return CommonResponse.error("审批回调失败，单据推送流水失败！");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		// 合同是否被其他单据引用
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况" + res.isSuccess() + "----" + res.getMsg());
		if (!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}
		StopEntity entity = service.selectById(billId);
		service.validateTime(BeanMapper.map(entity, StopVO.class), MaterialConstant.弃审);
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		StopEntity entity = service.selectById(billId);
		// 删除单价流水
		List<Long> ids = new ArrayList<>();
		ids.add(billId);
		if (!priceFlowService.delFlow(ids, billTypeCode)) {
			return CommonResponse.error("撤回失败，单据推送流水失败！");
		}
		logger.info("删除单价流水成功--" + billId+billTypeCode);
		// 推送租赁流水未生效
		if(!rmatFlowService.insertStopFlow(entity, billTypeCode, RmatCommonConsts.NO)){
			return CommonResponse.error("撤回失败，单据推送流水失败！");
		}
		return CommonResponse.success();
	}
}

==> cscec5b-rmat-impl-3.0.1-20241109.065542-320-sources.jar: com/ejianc/business/rmat/service/impl/StopBpmServiceImpl.java <==
package com.ejianc.business.rmat.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ejianc.business.rmat.bean.StartEntity;
import com.ejianc.business.rmat.bean.StopEntity;
import com.ejianc.business.rmat.consts.MaterialConstant;
import com.ejianc.business.rmat.consts.RmatCommonConsts;
import com.ejianc.business.rmat.service.IPriceFlowService;
import com.ejianc.business.rmat.service.IRmatFlowService;
import com.ejianc.business.rmat.service.IStartService;
import com.ejianc.business.rmat.service.IStopService;
import com.ejianc.business.rmat.vo.StopVO;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service("stop")
public class StopBpmServiceImpl implements ICommonBusinessService {
	private final Logger logger = LoggerFactory.getLogger(getClass());
	@Autowired
	private IRmatFlowService rmatFlowService;
	@Autowired
	private IStopService service;
	@Autowired
	private IPriceFlowService priceFlowService;
	@Autowired
	private IBillTypeApi billTypeApi;
	@Autowired
	private IStartService startService;

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		StopEntity entity = service.selectById(billId);
		// 推送租赁流水生效
		if(!rmatFlowService.insertStopFlow(entity, billTypeCode, RmatCommonConsts.YES)){
			return CommonResponse.error("审批回调失败，单据推送流水失败！");
		}

		// 推送单价流水生效
		if (!priceFlowService.insertStopFlow(entity, billTypeCode)) {
			return CommonResponse.error("审批回调失败，单据推送流水失败！");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		// 合同是否被其他单据引用
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况" + res.isSuccess() + "----" + res.getMsg());
		if (!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能弃审！");
		}
		StopEntity entity = service.selectById(billId);
		service.validateTime(BeanMapper.map(entity, StopVO.class), MaterialConstant.弃审);
		LambdaQueryWrapper<StartEntity> query = new LambdaQueryWrapper<>();
		query.eq(StartEntity::getProjectId, entity.getProjectId());
		query.eq(StartEntity::getContractId, entity.getContractId());
		query.orderByDesc(StartEntity::getStartTime);
		query.last("limit 1");
		StartEntity startEntity = startService.getOne(query, false);
		if(null != startEntity && entity.getStopTime().compareTo(startEntity.getStartTime()) <= 0){
			return CommonResponse.error("撤回失败，该单据已存在下游停租启租单！");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		StopEntity entity = service.selectById(billId);
		// 删除单价流水
		List<Long> ids = new ArrayList<>();
		ids.add(billId);
		if (!priceFlowService.delFlow(ids, billTypeCode)) {
			return CommonResponse.error("撤回失败，单据推送流水失败！");
		}
		logger.info("删除单价流水成功--" + billId+billTypeCode);
		// 推送租赁流水未生效
		if(!rmatFlowService.insertStopFlow(entity, billTypeCode, RmatCommonConsts.NO)){
			return CommonResponse.error("撤回失败，单据推送流水失败！");
		}
		return CommonResponse.success();
	}
}
